"""UI components for LazyLabel."""

from .control_panel import ControlPanel
from .hotkey_dialog import HotkeyDialog
from .main_window import MainWindow
from .right_panel import RightPanel

__all__ = ["MainWindow", "ControlPanel", "RightPanel", "HotkeyDialog"]
